@@ -1,4 +1,4 @@
-from delft_physics_lab.delft_physics_lab.utils import *
+from ..utils import *
 from datetime import datetime
 
 
